"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.basename = basename;
exports.dirname = dirname;
exports.filenameExtension = filenameExtension;
exports.getPathExtension = getPathExtension;
exports.pathInfo = pathInfo;

/**
 * Returns the basename of a path.
 * @param {string} path A path.
 * @return {string} The basename of the given path.
 */
function basename(path) {
  return path.split(/[\\/]/).pop();
}
/**
 * Get the extension of a path (i.e untitled.png => png).
 * @param {string} path the path to strip the extension from.
 * @returns {string} the path extension or an empty string.
 */


function getPathExtension(path) {
  var str = path + "";
  var dotP = str.lastIndexOf(".") + 1;
  return !dotP ? "" : dotP !== str.length ? str.substring(dotP) : "";
}
/**
 * Returns info about a path.
 * @param {string} path The path.
 * @param {Object} [options] Optional options object. Defaults to all. If passed with override 
 * all other properties.
 * @param {boolean} [options.all] all flag. Defaults to true.
 * @param {boolean} [options.dirname] dirname flag. Defaults to true.
 * @param {boolean} [options.basename] basename flag. Defaults to true.
 * @param {boolean} [options.extension] extension flag. Defaults to true.
 * @param {boolean} [options.filename] filename flag. Defaults to true.
 */


function pathInfo(path) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    all: true,
    dirname: true,
    basename: true,
    extension: true,
    filename: true
  };
  if (!path) return {};
  var override = !options || options.all; // Gather path info

  var tmpArr = {};

  if (override || options.dirname) {
    var dirName = path.replace(/\\/g, "/").replace(/\/[^/]*\/?$/, ""); // dirname

    tmpArr.dirname = dirName === path ? "." : dirName;
  }

  var haveBasename = false;

  if (override || options.basename) {
    if (haveBasename === false) haveBasename = basename(path);
    tmpArr.basename = haveBasename;
  }

  var haveExtension = false;

  if (override || options.extension) {
    if (haveBasename === false) haveBasename = basename(path);
    if (haveExtension === false) haveExtension = getPathExtension(haveBasename);
    if (haveExtension !== false) tmpArr.extension = haveExtension;
  }

  var haveFilename = false;

  if (override || options.filename) {
    if (haveBasename === false) haveBasename = basename(path);
    if (haveExtension === false) haveExtension = getPathExtension(haveBasename);
    if (haveFilename === false) haveFilename = haveBasename.slice(0, haveBasename.length - (haveExtension ? haveExtension.length + 1 : haveExtension === false ? 0 : 1));
    tmpArr.filename = haveFilename;
  }

  return tmpArr;
}
/**
 * Returns the extension of a filename.
 * @param {string} filename The filename.
 * @return {string} The extension of the given filename.
 */


function filenameExtension(filename) {
  var info = pathInfo(filename, {
    extension: true
  });
  if (!info) return "";
  return info.extension;
}
/**
 * Returns the dirname of a path.
 * @param {string} path A path.
 * @return {string} The dirname of the given path.
 */


function dirname(path) {
  var info = pathInfo(path, {
    dirname: true
  });
  if (!info) return "";
  return info.dirname;
}
//# sourceMappingURL=path.js.map