"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkNetwork = checkNetwork;
exports.newXHR = newXHR;
exports.waitForNetwork = waitForNetwork;

/**
 * Returns a new XMLHttpRequest or ActiveXObject object.
 * @return {XMLHttpRequest|ActiveXObject}
 */
function newXHR() {
  return window.ActiveXObject && new window.ActiveXObject("Microsoft.XMLHTTP") || new XMLHttpRequest();
}
/**
 * Checks whether the network is reachable or not.
 * @param {string} URI The uri to use for the request. Note: A GET query string
 * with a random parameter is always appended to the URI.
 * @return {Promise<boolean>} A promise which resolves to true if the network is reachable.
 * Note: the returned promise always resolves to true when this code runs on localhost.
 */


function checkNetwork() {
  var URI = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  // Handle IE and more capable browsers.
  var xhrObj = newXHR();
  return new Promise(function (resolve) {
    // Issue request and handle response.
    try {
      xhrObj.onreadystatechange = function () {
        if (xhrObj.readyState == 4) {
          resolve(xhrObj.status >= 200 && (xhrObj.status < 300 || xhrObj.status === 304));
        }
      }; // Open new request as a HEAD to the root hostname with a random param to bust the cache.


      xhrObj.open("HEAD", (URI || "//" + window.location.hostname + (window.location.port != 80 ? ":" + window.location.port : "")) + "?rand=" + Math.floor((1 + Math.random()) * 0x10000), // 0x10000 = 2^16
      true);
      xhrObj.send();
    } catch (error) {
      resolve(false);
    }
  });
}
/**
 * Note: If the network is available, the promise will resolve almost immediately.
 * @param {number} retryInterval An interval in milliseconds to wait before the next network check.
 * @return {Promise} A promise which resolves when the network is available.
 */


function waitForNetwork() {
  var retryInterval = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 3000;
  return new Promise(function (resolve) {
    checkNetwork().then(function (reachable) {
      if (reachable) {
        resolve();
      } else {
        var interval = setInterval(function () {
          checkNetwork().then(function (reachable) {
            if (reachable) {
              clearInterval(interval);
              resolve();
            }
          });
        }, retryInterval);
      }
    });
  });
}
//# sourceMappingURL=network.js.map